==> marketing_plugin-0.0.1.tar.gz: lib/plugin_codelab.dart <==
import 'dart:ffi';
import 'dart:io';

import 'package:facebook_audience_network/facebook_audience_network.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'admanager_banner.dart';
import 'admanager_native.dart';
import 'banner_view.dart';
import 'native_view.dart';
import 'plugin_codelab_platform_interface.dart';


class PluginCodelab {
  Future getCallAppOpenAds() async {
    return await PluginCodelabPlatform.instance.getCallAppOpenAds();
  }

  Future getCallInterstitialAds(i) async {
    if (await issdkads()) {
      String fbIntersttial = await FBinterstitialAd();
      if (fbIntersttial.isNotEmpty) {
        if (await isEveryads()) {
         if (await isfacebookads()) {
            return await loadFBInterstitial();
          } else {
            return loadGoogleInterstitial();
          }
        } else if (i == 2) {
           if (await isfacebookads()) {
            return await loadFBInterstitial();
          } else {
            return loadGoogleInterstitial();
          }
        }
      }
    } else {
      return await PluginCodelabPlatform.instance.getCallInterstitialAds();
    }
  }

  Future getCallCloseInterstitialAds(j) async {
    if (await issdkads()) {
      if (await isfacebookads()) {
        if (await isBackgroudAds()) {
          if (await isEveryads()) {
            if (await isfacebookads()) {
              return await loadFBInterstitial();
            } else {
              return loadGoogleInterstitial();
            }
          } else if (j == 2) {
             if (await isfacebookads()) {
              return await loadFBInterstitial();
            } else {
              return loadGoogleInterstitial();
            }
          }
        }
      }
    } else {
      return await PluginCodelabPlatform.instance.getCallCloseInterstitialAds();
    }
  }

  loadFBInterstitial() async {
    String fbIntersttial = await FBinterstitialAd();
    if (fbIntersttial.isNotEmpty) {
      return await FacebookInterstitialAd.loadInterstitialAd(
          placementId: fbIntersttial,
          listener: (result, value) async {
            if (result == InterstitialAdResult.LOADED) {
              FacebookInterstitialAd.showInterstitialAd(delay: 1000);
            }
            if (result == InterstitialAdResult.ERROR) {
              await FacebookInterstitialAd.destroyInterstitialAd();
            }
          });
    }
  }

  loadGoogleInterstitial() async {
    dynamic admanagerIds = await adManagerIds();
    return InterstitialAd.load(
        adUnitId: admanagerIds['interstitial'],
        request: AdRequest(),
        adLoadCallback: InterstitialAdLoadCallback(
          onAdLoaded: (InterstitialAd interstitialAd) {
            _showInterstitialAd(interstitialAd);
          },
          onAdFailedToLoad: (LoadAdError error) {
            print('InterstitialAd failed to load: $error.');
          },
        ));
  }

  void _showInterstitialAd(interstitialAd) {
    if (interstitialAd == null) {
      print('Warning: attempt to show interstitial before loaded.');
      return;
    }
    interstitialAd!.fullScreenContentCallback = FullScreenContentCallback(
      onAdShowedFullScreenContent: (InterstitialAd ad) =>
          print('ad onAdShowedFullScreenContent.'),
      onAdDismissedFullScreenContent: (InterstitialAd ad) {
        print('$ad onAdDismissedFullScreenContent.');
        ad.dispose();
      },
      onAdFailedToShowFullScreenContent: (InterstitialAd ad, AdError error) {
        print('$ad onAdFailedToShowFullScreenContent: $error');
        ad.dispose();
        loadGoogleInterstitial();
      },
    );
    interstitialAd!.show();
  }

  Future adsONorOFf() async {
    MobileAds.instance.initialize();
    FacebookAudienceNetwork.init();

    return await PluginCodelabPlatform.instance.adsONorOFf();
  }

  Future onesignalKey() async {
    return await PluginCodelabPlatform.instance.onesignalKey();
  }

  Future isCustomeads() async {
    return await PluginCodelabPlatform.instance.isCustomeads();
  }

  Future isnativead() async {
    return await PluginCodelabPlatform.instance.isnativead();
  }

  Future privacyPolicy() async {
    return await PluginCodelabPlatform.instance.privacyPolicy();
  }

  Future lottiurl() async {
    return await PluginCodelabPlatform.instance.lottiurl();
  }

  Future dummyScreen() async {
    return await PluginCodelabPlatform.instance.dummyScreen();
  }

  Future<Map> quiz() async {
    return await PluginCodelabPlatform.instance.quiz();
  }

  Future FBbannerAd() async {
    return await PluginCodelabPlatform.instance.FBbannerAd();
  }

  Future FBrewardedAd() async {
    return await PluginCodelabPlatform.instance.FBrewardedAd();
  }

  Future FBinterstitialAd() async {
    return await PluginCodelabPlatform.instance.FBinterstitialAd();
  }

  Future FBnativeAd() async {
    return await PluginCodelabPlatform.instance.FBnativeAd();
  }

  Future issdkads() async {
    return await PluginCodelabPlatform.instance.issdkads();
  }

  Future isEveryads() async {
    return await PluginCodelabPlatform.instance.isEveryads();
  }

  Future isBackgroudAds() async {
    return await PluginCodelabPlatform.instance.isBackgroudAds();
  }

  Future colors() async {
    return await PluginCodelabPlatform.instance.colors();
  }

  Future adManagerIds() async {
    return await PluginCodelabPlatform.instance.adManagerIds();
  }

  Future isfacebookads() async {
    return await PluginCodelabPlatform.instance.isfacebookads();
  }
  Future isrecycleAds() async {
    return await PluginCodelabPlatform.instance.isrecycleAds();
  }

  Widget banner(Function callBack) {
    return FutureBuilder(
      future: issdkads(),
      builder: (context, snapshot) {
        if (!snapshot.hasData || snapshot.hasError) {
          return Container();
        }
        if (snapshot.data) {
          return FutureBuilder(
            future: isfacebookads(),
            builder: (context, fbsnapshot) {
              if (!fbsnapshot.hasData || fbsnapshot.hasError) {
                return Container();
              }
              if (fbsnapshot.data) {
                return FutureBuilder(
                    future: FBbannerAd(),
                    builder: (context, snapshots) {
                      if (!snapshots.hasData || snapshots.hasError) {
                        return Container();
                      }
                      return Container(
                        alignment: Alignment(0.5, 1),
                        child: FacebookBannerAd(
                          placementId: snapshots.data,
                          keepAlive: true,
                          bannerSize: BannerSize.STANDARD,
                          listener: (result, value) {
                            switch (result) {
                              case BannerAdResult.ERROR:
                                print("Error: $value");
                                break;
                              case BannerAdResult.LOADED:
                                print("Loaded: $value");
                                break;
                              case BannerAdResult.CLICKED:
                                print("Clicked: $value");
                                break;
                              case BannerAdResult.LOGGING_IMPRESSION:
                                print("Logging Impression: $value");
                                break;
                            }
                          },
                        ),
                      );
                    });
              } else {
                return FutureBuilder(
                  future: adManagerIds(),
                  builder: (context, snapshot) {
                    if (!snapshot.hasData || snapshot.hasError) {
                      return Container();
                    }
                    return BannerExample(ids: snapshot.data['banner']);
                  },
                );
              }
            },
          );
        } else {
          return BlurViewBannerWidget(
            onBlurBannerViewWidgetCreated: (controller) {
              callBack.call();
            },
          );
        }
      },
    );
  }

  loadRewardedVideoAd() async {
    if (await issdkads()) {
      String rwardId = await FBrewardedAd();
      FacebookRewardedVideoAd.loadRewardedVideoAd(
        placementId: rwardId,
        listener: (result, value) {
          print("Rewarded Ad: $result --> $value");
          if (result == RewardedVideoAdResult.LOADED) {
            Future.delayed(const Duration(seconds: 1), () {
              FacebookRewardedVideoAd.showRewardedVideoAd();
            });
          }
          if (result == RewardedVideoAdResult.ERROR) {
            FacebookRewardedVideoAd.destroyRewardedVideoAd();
            loadRewardedVideoAd();
          }

          /// Once a Rewarded Ad has been closed and becomes invalidated,
          /// load a fresh Ad by calling this function.
          if (result == RewardedVideoAdResult.VIDEO_CLOSED &&
              (value == true || value["invalidated"] == true)) {}
        },
      );
    } else {
      await PluginCodelabPlatform.instance.showreward();
    }
  }

  Widget native(Function callBack, MyAds type) {
    return FutureBuilder(
      future: issdkads(),
      initialData: false,
      builder: (context, snapshot) {
        if (!snapshot.hasData || snapshot.hasError) {
          return Container();
        }
        if (snapshot.data) {
          return FutureBuilder(
            future: colors(),
            builder: (context, snapshotColor) {
              if (!snapshotColor.hasData || snapshotColor.hasError) {
                return Container();
              }
              return FutureBuilder(
                future: isCustomeads(), builder: (context, isCustomeads) {
                if (!isCustomeads.hasData || isCustomeads.hasError) {
                  return Container();
                }
                return FutureBuilder(
                  future: isfacebookads(),
                  builder: (context, isfbAds) {
                    if (!isfbAds.hasData || isfbAds.hasError) {
                      return Container();
                    }
                    if (isfbAds.data) {
                      return FutureBuilder(
                          future: FBnativeAd(),
                          builder: (context, snapshots) {
                            if (!snapshots.hasData ||
                                snapshots.hasError) {
                              return Container();
                            }
                            return FacebookNativeAd(
                              placementId: snapshots.data,
                              adType: NativeAdType.NATIVE_AD,
                              width: double.infinity,
                              height: 300,
                              backgroundColor: isCustomeads.data
                                  ? HexColor
                                  .fromHex(
                                  snapshotColor.data['background'])
                                  : null,
                              titleColor:
                              isCustomeads.data ? HexColor.fromHex(
                                  snapshotColor.data['title']) : null,
                              descriptionColor:
                              isCustomeads.data ? HexColor.fromHex(
                                  snapshotColor.data['title']) : null,
                              buttonColor:
                              isCustomeads.data ? HexColor.fromHex(
                                  snapshotColor.data['button']) : null,
                              buttonTitleColor:
                              isCustomeads.data ? HexColor.fromHex(
                                  snapshotColor.data['text']) : null,
                              buttonBorderColor:
                              isCustomeads.data ? HexColor.fromHex(
                                  snapshotColor.data['button']) : null,
                              isMediaCover: true,
                              keepAlive: true,
                              //set true if you do not want adview to refresh on widget rebuild
                              keepExpandedWhileLoading: false,
                              // set false if you want to collapse the native ad view when the ad is loading
                              expandAnimationDuraion: 300,
                              //in milliseconds. Expands the adview with animation when ad is loaded
                              listener: (result, value) {
                                callBack.call();
                                print("Native Ad: $result --> $value");
                              },
                            );
                          });
                    } else {
                      return FutureBuilder(
                          future: adManagerIds(),
                          builder: (context, snapshots) {
                            if (!snapshots.hasData ||
                                snapshots.hasError) {
                              return Container();
                            }
                            callBack.call();
                            return NativeExample(
                                colors: snapshotColor.data,
                                isCustomeads: isCustomeads.data,
                                ids: snapshots.data['native']);
                          });
                    }
                    return Container();
                  },
                );
              },);
            },
          );
        } else {
          return BlurViewWidget(
            type: getNativeAdType(type),
            onBlurViewWidgetCreated:  (controller) {
              callBack.call();
            },

          );
        }
      },
    );
  }

  getNativeAdType(type) {
    switch (type) {
      case MyAds.nativeCustome:
        return '0';
        break;
      case MyAds.nativeNormal:
        return '1';
        break;
      case MyAds.nativeRegular:
        return '2';
        break;
      case MyAds.nativeBigUpMedia:
        return '7';
      case MyAds.nativeBigNoMedia:
        return '8';
        break;
        
      case MyAds.nativeSmall:
        return '3';
        break;
      case MyAds.nativeSmallDown:
        return '4';
        break;
      case MyAds.nativeSmallSide:
        return '5';
        break;
      case MyAds.nativeSmallUp:
        return '6';
      
    }
  }
}

extension HexColor on Color {
  /// String is in the format "aabbcc" or "ffaabbcc" with an optional leading "#".
  static Color fromHex(String hexString) {
    if (hexString.isEmpty) {
      return Colors.white;
    }
    final buffer = StringBuffer();
    buffer.write(hexString.replaceFirst('#', ''));
    return Color(int.parse(buffer.toString(), radix: 16));
  }

  static Color fromHexColor(String hexString) {
    if (hexString.isEmpty) {
      return Colors.white;
    }
    final buffer = StringBuffer();
    if (hexString.length == 6 || hexString.length == 7) buffer.write('ff');
    buffer.write(hexString.replaceFirst('#', ''));
    return Color(int.parse(buffer.toString(), radix: 16));
  }

  /// Prefixes a hash sign if [leadingHashSign] is set to `true` (default is `true`).
  String toHex({bool leadingHashSign = true}) => '${leadingHashSign ? '#' : ''}'
      '${alpha.toRadixString(16).padLeft(2, '0')}'
      '${red.toRadixString(16).padLeft(2, '0')}'
      '${green.toRadixString(16).padLeft(2, '0')}'
      '${blue.toRadixString(16).padLeft(2, '0')}';
}
enum MyAds {
  nativeCustome,
  nativeNormal,
  nativeRegular,
  nativeSmall,
  nativeSmallDown,
  nativeSmallSide,
  nativeSmallUp,
  nativeBigUpMedia,
  nativeBigNoMedia,
}

==> marketing_plugin-0.0.4.tar.gz: lib/plugin_codelab.dart <==

import 'package:facebook_audience_network/facebook_audience_network.dart';
import 'package:flutter/material.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'admanager_banner.dart';
import 'admanager_native.dart';
import 'banner_view.dart';
import 'native_view.dart';
import 'plugin_codelab_platform_interface.dart';


class PluginCodelab {
  Future getCallAppOpenAds() async {
    return await PluginCodelabPlatform.instance.getCallAppOpenAds();
  }

  Future getCallInterstitialAds(i) async {
    if (await issdkads()) {
      String fbIntersttial = await FBinterstitialAd();
      if (fbIntersttial.isNotEmpty) {
        if (await isEveryads()) {
         if (await isfacebookads()) {
            return await loadFBInterstitial();
          } else {
            return loadGoogleInterstitial();
          }
        } else if (i == 2) {
           if (await isfacebookads()) {
            return await loadFBInterstitial();
          } else {
            return loadGoogleInterstitial();
          }
        }
      }
    } else {
      return await PluginCodelabPlatform.instance.getCallInterstitialAds();
    }
  }

  Future getCallCloseInterstitialAds(j) async {
    if (await issdkads()) {
      if (await isfacebookads()) {
        if (await isBackgroudAds()) {
          if (await isEveryads()) {
            if (await isfacebookads()) {
              return await loadFBInterstitial();
            } else {
              return loadGoogleInterstitial();
            }
          } else if (j == 2) {
             if (await isfacebookads()) {
              return await loadFBInterstitial();
            } else {
              return loadGoogleInterstitial();
            }
          }
        }
      }
    } else {
      return await PluginCodelabPlatform.instance.getCallCloseInterstitialAds();
    }
  }

  loadFBInterstitial() async {
    String fbIntersttial = await FBinterstitialAd();
    if (fbIntersttial.isNotEmpty) {
      return await FacebookInterstitialAd.loadInterstitialAd(
          placementId: fbIntersttial,
          listener: (result, value) async {
            if (result == InterstitialAdResult.LOADED) {
              FacebookInterstitialAd.showInterstitialAd(delay: 1000);
            }
            if (result == InterstitialAdResult.ERROR) {
              await FacebookInterstitialAd.destroyInterstitialAd();
            }
          });
    }
  }

  loadGoogleInterstitial() async {
    dynamic admanagerIds = await adManagerIds();
    return InterstitialAd.load(
        adUnitId: admanagerIds['interstitial'],
        request: const AdRequest(),
        adLoadCallback: InterstitialAdLoadCallback(
          onAdLoaded: (InterstitialAd interstitialAd) {
            _showInterstitialAd(interstitialAd);
          },
          onAdFailedToLoad: (LoadAdError error) {
            print('InterstitialAd failed to load: $error.');
          },
        ));
  }

  void _showInterstitialAd(interstitialAd) {
    if (interstitialAd == null) {
      print('Warning: attempt to show interstitial before loaded.');
      return;
    }
    interstitialAd!.fullScreenContentCallback = FullScreenContentCallback(
      onAdShowedFullScreenContent: (InterstitialAd ad) =>
          print('ad onAdShowedFullScreenContent.'),
      onAdDismissedFullScreenContent: (InterstitialAd ad) {
        print('$ad onAdDismissedFullScreenContent.');
        ad.dispose();
      },
      onAdFailedToShowFullScreenContent: (InterstitialAd ad, AdError error) {
        print('$ad onAdFailedToShowFullScreenContent: $error');
        ad.dispose();
        loadGoogleInterstitial();
      },
    );
    interstitialAd!.show();
  }

  Future adsONorOFf() async {
    MobileAds.instance.initialize();
    FacebookAudienceNetwork.init();

    return await PluginCodelabPlatform.instance.adsONorOFf();
  }

  Future onesignalKey() async {
    return await PluginCodelabPlatform.instance.onesignalKey();
  }

  Future isCustomeads() async {
    return await PluginCodelabPlatform.instance.isCustomeads();
  }

  Future isnativead() async {
    return await PluginCodelabPlatform.instance.isnativead();
  }

  Future privacyPolicy() async {
    return await PluginCodelabPlatform.instance.privacyPolicy();
  }

  Future lottiurl() async {
    return await PluginCodelabPlatform.instance.lottiurl();
  }

  Future dummyScreen() async {
    return await PluginCodelabPlatform.instance.dummyScreen();
  }

  Future<Map> quiz() async {
    return await PluginCodelabPlatform.instance.quiz();
  }

  Future FBbannerAd() async {
    return await PluginCodelabPlatform.instance.FBbannerAd();
  }

  Future FBrewardedAd() async {
    return await PluginCodelabPlatform.instance.FBrewardedAd();
  }

  Future FBinterstitialAd() async {
    return await PluginCodelabPlatform.instance.FBinterstitialAd();
  }

  Future FBnativeAd() async {
    return await PluginCodelabPlatform.instance.FBnativeAd();
  }

  Future issdkads() async {
    return await PluginCodelabPlatform.instance.issdkads();
  }

  Future isEveryads() async {
    return await PluginCodelabPlatform.instance.isEveryads();
  }

  Future isBackgroudAds() async {
    return await PluginCodelabPlatform.instance.isBackgroudAds();
  }

  Future colors() async {
    return await PluginCodelabPlatform.instance.colors();
  }

  Future adManagerIds() async {
    return await PluginCodelabPlatform.instance.adManagerIds();
  }

  Future isfacebookads() async {
    return await PluginCodelabPlatform.instance.isfacebookads();
  }
  Future isrecycleAds() async {
    return await PluginCodelabPlatform.instance.isrecycleAds();
  }

  Widget banner(Function callBack) {
    return FutureBuilder(
      future: issdkads(),
      builder: (context, snapshot) {
        if (!snapshot.hasData || snapshot.hasError) {
          return Container();
        }
        if (snapshot.data) {
          return FutureBuilder(
            future: isfacebookads(),
            builder: (context, fbsnapshot) {
              if (!fbsnapshot.hasData || fbsnapshot.hasError) {
                return Container();
              }
              if (fbsnapshot.data) {
                return FutureBuilder(
                    future: FBbannerAd(),
                    builder: (context, snapshots) {
                      if (!snapshots.hasData || snapshots.hasError) {
                        return Container();
                      }
                      return Container(
                        alignment: const Alignment(0.5, 1),
                        child: FacebookBannerAd(
                          placementId: snapshots.data,
                          keepAlive: true,
                          bannerSize: BannerSize.STANDARD,
                          listener: (result, value) {
                            switch (result) {
                              case BannerAdResult.ERROR:
                                print("Error: $value");
                                break;
                              case BannerAdResult.LOADED:
                                print("Loaded: $value");
                                break;
                              case BannerAdResult.CLICKED:
                                print("Clicked: $value");
                                break;
                              case BannerAdResult.LOGGING_IMPRESSION:
                                print("Logging Impression: $value");
                                break;
                            }
                          },
                        ),
                      );
                    });
              } else {
                return FutureBuilder(
                  future: adManagerIds(),
                  builder: (context, snapshot) {
                    if (!snapshot.hasData || snapshot.hasError) {
                      return Container();
                    }
                    return BannerExample(ids: snapshot.data['banner']);
                  },
                );
              }
            },
          );
        } else {
          return BlurViewBannerWidget(
            onBlurBannerViewWidgetCreated: (controller) {
              callBack.call();
            },
          );
        }
      },
    );
  }

  loadRewardedVideoAd() async {
    if (await issdkads()) {
      String rwardId = await FBrewardedAd();
      FacebookRewardedVideoAd.loadRewardedVideoAd(
        placementId: rwardId,
        listener: (result, value) {
          print("Rewarded Ad: $result --> $value");
          if (result == RewardedVideoAdResult.LOADED) {
            Future.delayed(const Duration(seconds: 1), () {
              FacebookRewardedVideoAd.showRewardedVideoAd();
            });
          }
          if (result == RewardedVideoAdResult.ERROR) {
            FacebookRewardedVideoAd.destroyRewardedVideoAd();
            loadRewardedVideoAd();
          }

          /// Once a Rewarded Ad has been closed and becomes invalidated,
          /// load a fresh Ad by calling this function.
          if (result == RewardedVideoAdResult.VIDEO_CLOSED &&
              (value == true || value["invalidated"] == true)) {}
        },
      );
    } else {
      await PluginCodelabPlatform.instance.showreward();
    }
  }

  Widget native(Function callBack, MyAds type) {
    return FutureBuilder(
      future: issdkads(),
      initialData: false,
      builder: (context, snapshot) {
        if (!snapshot.hasData || snapshot.hasError) {
          return Container();
        }
        if (snapshot.data) {
          return FutureBuilder(
            future: colors(),
            builder: (context, snapshotColor) {
              if (!snapshotColor.hasData || snapshotColor.hasError) {
                return Container();
              }
              return FutureBuilder(
                future: isCustomeads(), builder: (context, isCustomeads) {
                if (!isCustomeads.hasData || isCustomeads.hasError) {
                  return Container();
                }
                return FutureBuilder(
                  future: isfacebookads(),
                  builder: (context, isfbAds) {
                    if (!isfbAds.hasData || isfbAds.hasError) {
                      return Container();
                    }
                    if (isfbAds.data) {
                      return FutureBuilder(
                          future: FBnativeAd(),
                          builder: (context, snapshots) {
                            if (!snapshots.hasData ||
                                snapshots.hasError) {
                              return Container();
                            }
                            return FacebookNativeAd(
                              placementId: snapshots.data,
                              adType: NativeAdType.NATIVE_AD,
                              width: double.infinity,
                              height: 300,
                              backgroundColor: isCustomeads.data
                                  ? HexColor
                                  .fromHex(
                                  snapshotColor.data['background'])
                                  : null,
                              titleColor:
                              isCustomeads.data ? HexColor.fromHex(
                                  snapshotColor.data['title']) : null,
                              descriptionColor:
                              isCustomeads.data ? HexColor.fromHex(
                                  snapshotColor.data['title']) : null,
                              buttonColor:
                              isCustomeads.data ? HexColor.fromHex(
                                  snapshotColor.data['button']) : null,
                              buttonTitleColor:
                              isCustomeads.data ? HexColor.fromHex(
                                  snapshotColor.data['text']) : null,
                              buttonBorderColor:
                              isCustomeads.data ? HexColor.fromHex(
                                  snapshotColor.data['button']) : null,
                              isMediaCover: true,
                              keepAlive: true,
                              //set true if you do not want adview to refresh on widget rebuild
                              keepExpandedWhileLoading: false,
                              // set false if you want to collapse the native ad view when the ad is loading
                              expandAnimationDuraion: 300,
                              //in milliseconds. Expands the adview with animation when ad is loaded
                              listener: (result, value) {
                                callBack.call();
                                print("Native Ad: $result --> $value");
                              },
                            );
                          });
                    } else {
                      return FutureBuilder(
                          future: adManagerIds(),
                          builder: (context, snapshots) {
                            if (!snapshots.hasData ||
                                snapshots.hasError) {
                              return Container();
                            }
                            callBack.call();
                            return NativeExample(
                                colors: snapshotColor.data,
                                isCustomeads: isCustomeads.data,
                                ids: snapshots.data['native']);
                          });
                    }
                  },
                );
              },);
            },
          );
        } else {
          return BlurViewWidget(
            type: getNativeAdType(type),
            onBlurViewWidgetCreated:  (controller) {
              callBack.call();
            },

          );
        }
      },
    );
  }

  getNativeAdType(type) {
    switch (type) {
      case MyAds.nativeCustome:
        return '0';
        break;
      case MyAds.nativeNormal:
        return '1';
        break;
      case MyAds.nativeRegular:
        return '2';
        break;
      case MyAds.nativeBigUpMedia:
        return '7';
      case MyAds.nativeBigNoMedia:
        return '8';
        break;
      case MyAds.nativeSmall:
        return '3';
        break;
      case MyAds.nativeSmallDown:
        return '4';
        break;
      case MyAds.nativeSmallSide:
        return '5';
        break;
      case MyAds.nativeSmallUp:
        return '6';
    }
  }
}

extension HexColor on Color {
  /// String is in the format "aabbcc" or "ffaabbcc" with an optional leading "#".
  static Color fromHex(String hexString) {
    if (hexString.isEmpty) {
      return Colors.white;
    }
    final buffer = StringBuffer();
    buffer.write(hexString.replaceFirst('#', ''));
    return Color(int.parse(buffer.toString(), radix: 16));
  }

  static Color fromHexColor(String hexString) {
    if (hexString.isEmpty) {
      return Colors.white;
    }
    final buffer = StringBuffer();
    if (hexString.length == 6 || hexString.length == 7) buffer.write('ff');
    buffer.write(hexString.replaceFirst('#', ''));
    return Color(int.parse(buffer.toString(), radix: 16));
  }

  /// Prefixes a hash sign if [leadingHashSign] is set to `true` (default is `true`).
  String toHex({bool leadingHashSign = true}) => '${leadingHashSign ? '#' : ''}'
      '${alpha.toRadixString(16).padLeft(2, '0')}'
      '${red.toRadixString(16).padLeft(2, '0')}'
      '${green.toRadixString(16).padLeft(2, '0')}'
      '${blue.toRadixString(16).padLeft(2, '0')}';
}
enum MyAds {
  nativeCustome,
  nativeNormal,
  nativeRegular,
  nativeSmall,
  nativeSmallDown,
  nativeSmallSide,
  nativeSmallUp,
  nativeBigUpMedia,
  nativeBigNoMedia,
}
